Enum Event
#[non_exhaustive]pub enum Event {
StartConfigure {
width: u32,
height: u32,
anchor_x: i32,
anchor_y: i32,
anchor_width: u32,
anchor_height: u32,
serial: u32,
},
Repositioned {
token: u32,
},
}wayland and Linux only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
StartConfigure
configure the popup surface
The start_configure event updates the popup geometry and marks the start of a configure sequence.
The anchor_* arguments represent the geometry of the anchor to which the popup was attached, relative to the upper left corner of the popup’s surface. Note that this makes anchor_x, anchor_y the reverse of the what they represent in xdg_popup.
A configure sequence is a set of one or more events configuring the state of the input_popup_surface, starting with this event and ending with input_method.done. After the input_method.done event, the configure sequence is considered submitted.
State set by event in a configure sequence is conceptually double-buffered. Every argument overwrites its previous value. The state change should get applied atomically with the input_method.done ending the sequence, and the value of serial should return to the undefined value.
Events on the input_popup_surface object received outside a configure sequence (while serial is undefined) must be ignored by the client.
A configure sequence shall be sent every time the compositor (re)positions the popup, or the shape of the anchor changes, for example after popup creation, or in response to text being typed and the text cursor moving.
The client may update the surface in response to input_method.done. Unless the popup is destroyed by the input_method.done, the client must reply with an .ack_configure request with the serial sent in the start_configure event at some point after the sequence ends and before committing the new surface.
If the client receives multiple configure sequences before it can respond to one, it is free to discard all but the last event it received.
Fields
Repositioned
signal the completion of a reposition request
The compositor sends the .repositioned event in response to the .reposition request to notify about its completion.
The new geometry of the popup can be communicated using additional events within a configure sequence including:
- input_popup_surface.start_configure, and
- the .anchor_position event to update the relative position to the anchor.
When responding to a .reposition request, the token argument is the token passed in the that request.
This event is sent as part of a configure sequence. State set by this event is conceptually double-buffered. Every argument overwrites its previous value. The state change should get applied atomically with the next input_method.done event.
The client should optionally update the content of the popup, but must acknowledge the new popup configuration for the new position to take effect. See input_popup_surface.ack_configure for details.
Implementations