Enum Request
#[non_exhaustive]pub enum Request<'a> {
AckConfigure {
serial: u32,
},
Reposition {
positioner: XxInputPopupPositionerV1,
token: u32,
},
Destroy,
}wayland and Linux only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AckConfigure
acknowledge a configure sequence
This request notifies the compositor that the client updated its surface in response to a configure sequence.
The purpose of this request is to synchronize the updates of the surface geometry with the surface contents. For example, when the compositor assigns a size larger than prevously, the client must fill the additional space before the popup gets displayed to the user with the new size. When the compositor receives .ack_configure, it can proceed to draw the new size.
.ack_configure should be sent after every submitted configure sequence, passing along the serial received in it.
An .ack_configure request is conceptually double-buffered. Every request overrides the previous one. The request takes effect once the .commit request is sent on the corresponding surface.
If the client receives multiple configure sequences before it can respond to one, it may acknowledge only the last configure sequence by using its serial in the .ack_configure request.
Committing an .ack_configure request consumes the serial number sent with the request, as well as serial numbers sent by all configure sequences submitted on this input_popup_surface prior to the configure sequence referenced by the committed serial.
Committing this request with a serial that, for this surface, never appeared in a submitted configure sequence, or one that was already committed before, raises an invalid_serial error.
Reposition
recalculate the popup’s location
Reposition an already-mapped popup. The popup will be placed given the details in the passed input_popup_positioner object.
The request is processed immediately, without the need to issue wl_surface.commit, but the actual repositioning takes place later, after .ack_configure.
The compositor should reply with a configure sequence including:
- input_popup_surface.start_configure,
- input_popup_surface.repositioned, including the token passed in this request.
This will discard any parameters set by the previous positioner.
If multiple .reposition requests are sent before the .repositioned event is submitted as part of a configure sequence, the compositor may ignore all but the last one.
The new popup position will not take effect until the corresponding configure sequence is acknowledged by the client. See input_popup_surface.repositioned for details.
The token itself is opaque, and has no other special meaning.
Destroy
remove the popup
This destroys the popup. Explicitly destroying the input_popup_surface object will also dismiss the popup, and unmap the surface.
This is a destructor, once sent this object cannot be used any longer.
Implementations